@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 
 use base qw(App::Cmd::Command Dist::Joseki::Base);
@@ -72,48 +72,6 @@ Dist::Joseki::Cmd::Command - Base class for Dist::Joseki::Cmd commands
 
 None yet.
 
-Dist::Joseki::Cmd::Command inherits from L<App::Cmd::Command> and
-L<Dist::Joseki::Base>.
-
-The superclass L<App::Cmd::Command> defines these methods and functions:
-
-    new(), _option_processing_params(), _usage_text(), abstract(), app(),
-    command_names(), prepare(), usage(), usage_desc(), usage_error()
-
-The superclass L<App::Cmd::ArgProcessor> defines these methods and
-functions:
-
-    _process_args()
-
-The superclass L<Dist::Joseki::Base> defines these methods and functions:
-
-    assert_is_dist_base_dir(), print_header(), read_from_cmd(),
-    safe_system()
-
-The superclass L<Class::Accessor::Complex> defines these methods and
-functions:
-
-    carp(), cluck(), croak(), flatten(), mk_abstract_accessors(),
-    mk_array_accessors(), mk_boolean_accessors(),
-    mk_class_array_accessors(), mk_class_hash_accessors(),
-    mk_class_scalar_accessors(), mk_concat_accessors(),
-    mk_forward_accessors(), mk_hash_accessors(), mk_integer_accessors(),
-    mk_new(), mk_object_accessors(), mk_scalar_accessors(),
-    mk_set_accessors(), mk_singleton()
-
-The superclass L<Class::Accessor> defines these methods and functions:
-
-    _carp(), _croak(), _mk_accessors(), accessor_name_for(),
-    best_practice_accessor_name_for(), best_practice_mutator_name_for(),
-    follow_best_practice(), get(), make_accessor(), make_ro_accessor(),
-    make_wo_accessor(), mk_accessors(), mk_ro_accessors(),
-    mk_wo_accessors(), mutator_name_for(), set()
-
-The superclass L<Class::Accessor::Installer> defines these methods and
-functions:
-
-    install_accessor(), subname()
-
 =head1 METHODS
 
 =over 4
@@ -369,6 +327,47 @@ Returns a list of all hash values in no particular order.
 
 =back
 
+Dist::Joseki::Cmd::Command inherits from L<App::Cmd::Command> and
+L<Dist::Joseki::Base>.
+
+The superclass L<App::Cmd::Command> defines these methods and functions:
+
+    new(), _option_processing_params(), _usage_text(), abstract(), app(),
+    command_names(), prepare(), usage(), usage_desc(), usage_error()
+
+The superclass L<App::Cmd::ArgProcessor> defines these methods and
+functions:
+
+    _process_args()
+
+The superclass L<Dist::Joseki::Base> defines these methods and functions:
+
+    assert_is_dist_base_dir(), print_header(), read_from_cmd(),
+    safe_system()
+
+The superclass L<Class::Accessor::Complex> defines these methods and
+functions:
+
+    mk_abstract_accessors(), mk_array_accessors(), mk_boolean_accessors(),
+    mk_class_array_accessors(), mk_class_hash_accessors(),
+    mk_class_scalar_accessors(), mk_concat_accessors(),
+    mk_forward_accessors(), mk_hash_accessors(), mk_integer_accessors(),
+    mk_new(), mk_object_accessors(), mk_scalar_accessors(),
+    mk_set_accessors(), mk_singleton()
+
+The superclass L<Class::Accessor> defines these methods and functions:
+
+    _carp(), _croak(), _mk_accessors(), accessor_name_for(),
+    best_practice_accessor_name_for(), best_practice_mutator_name_for(),
+    follow_best_practice(), get(), make_accessor(), make_ro_accessor(),
+    make_wo_accessor(), mk_accessors(), mk_ro_accessors(),
+    mk_wo_accessors(), mutator_name_for(), set()
+
+The superclass L<Class::Accessor::Installer> defines these methods and
+functions:
+
+    install_accessor()
+
 =head1 TAGS
 
 If you talk about this module in blogs, on del.icio.us or anywhere else,
@@ -376,7 +375,7 @@ please use the C<distjoseki> tag.
 
 =head1 VERSION 
                    
-This document describes version 0.11 of L<Dist::Joseki::Cmd::Command>.
+This document describes version 0.12 of L<Dist::Joseki::Cmd::Command>.
 
 =head1 BUGS AND LIMITATIONS
 
@@ -402,7 +401,7 @@ Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 by Marcel GrE<uuml>nauer
+Copyright 2007-2008 by Marcel GrE<uuml>nauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
