@@ -8,7 +8,7 @@ use File::Temp 'tempfile';
 use IO::Prompt;
 
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 
 use base 'Dist::Joseki::Cmd::Command';
@@ -182,6 +182,32 @@ Dist::Joseki::Cmd::Command::change - 'change' command for Dist::Joseki::Cmd
 
 None yet.
 
+=head1 METHODS
+
+=over 4
+
+=item clear_commit_msg
+
+    $obj->clear_commit_msg;
+
+Clears the value.
+
+=item commit_msg
+
+    my $value = $obj->commit_msg;
+    $obj->commit_msg($value);
+
+A getter/setter method. If called without an argument, it returns the
+value. If called with a single argument, it appends to the current value.
+
+=item commit_msg_clear
+
+    $obj->commit_msg_clear;
+
+Clears the value.
+
+=back
+
 Dist::Joseki::Cmd::Command::change inherits from
 L<Dist::Joseki::Cmd::Command>.
 
@@ -214,8 +240,7 @@ The superclass L<Dist::Joseki::Base> defines these methods and functions:
 The superclass L<Class::Accessor::Complex> defines these methods and
 functions:
 
-    carp(), cluck(), croak(), flatten(), mk_abstract_accessors(),
-    mk_array_accessors(), mk_boolean_accessors(),
+    mk_abstract_accessors(), mk_array_accessors(), mk_boolean_accessors(),
     mk_class_array_accessors(), mk_class_hash_accessors(),
     mk_class_scalar_accessors(), mk_concat_accessors(),
     mk_forward_accessors(), mk_hash_accessors(), mk_integer_accessors(),
@@ -233,33 +258,7 @@ The superclass L<Class::Accessor> defines these methods and functions:
 The superclass L<Class::Accessor::Installer> defines these methods and
 functions:
 
-    install_accessor(), subname()
-
-=head1 METHODS
-
-=over 4
-
-=item clear_commit_msg
-
-    $obj->clear_commit_msg;
-
-Clears the value.
-
-=item commit_msg
-
-    my $value = $obj->commit_msg;
-    $obj->commit_msg($value);
-
-A getter/setter method. If called without an argument, it returns the
-value. If called with a single argument, it appends to the current value.
-
-=item commit_msg_clear
-
-    $obj->commit_msg_clear;
-
-Clears the value.
-
-=back
+    install_accessor()
 
 =head1 TAGS
 
@@ -268,7 +267,7 @@ please use the C<distjoseki> tag.
 
 =head1 VERSION 
                    
-This document describes version 0.11 of L<Dist::Joseki::Cmd::Command::change>.
+This document describes version 0.12 of L<Dist::Joseki::Cmd::Command::change>.
 
 =head1 BUGS AND LIMITATIONS
 
@@ -294,7 +293,7 @@ Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 by Marcel GrE<uuml>nauer
+Copyright 2007-2008 by Marcel GrE<uuml>nauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
